@@ -25,6 +25,18 @@ async def async_make_request(url, payload, headers=None):
         
         response.raise_for_status()  # Raise exception for non-2xx status codes
         return response  # Return the full response if needed
+
+
+def make_request(url, payload, headers=None):
+    # Log the payload and headers for debugging
+    logging.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
+    # Use json=payload instead of data= to ensure correct encoding and headers
+    response = requests.post(url, data=safe_json_dumps(payload), headers=headers)
+    # Log the response status and content
+    logging.debug(f"Received response: {response.status_code} - {response.text}")
+    return response  # Return the full response if needed
+
+
 def get_kwargs_bools(key, bools, **kwargs):
     bools[key] = kwargs.get(key)
     if key in kwargs:
@@ -130,7 +142,25 @@ async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_on
     except Exception as e:
         logging.error(f"Error fetching {method}: {e}")
         return []
-
+def call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,**kwargs):
+    """
+    A rate-limited caller that funnels into makeLimitedRpcCall.
+    """
+    params = params or []
+    url_1_only = True if url_1_only is None else url_1_only
+    url_2_only = False if url_2_only is None else url_2_only
+    unique_item = params[0] if params else params
+    try:
+        logging.debug(f"Fetching transaction for signature={unique_item}")
+        response = make_rate_limited_call(method=method, params=params,
+                                            url_1_only=url_1_only,
+                                            url_2_only=url_2_only,
+                                            **kwargs)
+        logging.debug(f"Raw response from {method} for {unique_item}.")
+        return response
+    except Exception as e:
+        logging.error(f"Error fetching {method}: {e}")
+        return []
 async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args,**kwargs):
     """
     Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
@@ -178,27 +208,83 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
             return result
     # If no response after all attempts, return empty or raise an exception
     return []
-def make_request(url=None, payload={}, headers=None, url_1_only=None, url_2_only=False,*args, **kwargs):
+
+def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args,**kwargs):
+    """
+    Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
+    After the 1st attempt, set url_1_only=False.
+    """
+    ogsettings = kwargs.get('solcatcherSettings',{})
+    solcatcherSettings=defaultSolcatcherSettings
+    solcatcherSettings.update(ogsettings)
+    kwargs['solcatcherSettings']=solcatcherSettings
+    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
+    for attempt in range(3):  # Retry logic
+        if attempt == 2:
+            url_2_only = True
+        if attempt == 1:
+            url_1_only = False
+        
+        result = call_solcatcher_py(
+            'make_limited_rpc_call',
+            method=method,
+            params=params,
+            url_1_only=url_1_only,
+            url_2_only=url_2_only,
+            solcatcherSettings=solcatcherSettings,
+            headers = headers,
+            **kwargs
+        )
+
+        if solcatcherSettings.get('getStatusCode'):
+            if isinstance(result,dict):
+                status_code = result.get('status_code')
+                results = result.get('result')
+                if status_code and status_code != 429:
+                    if ogsettings.get('getStatusCode'):
+                        return result
+                    else:
+                        del result['status_code']
+                    get_result = solcatcherSettings.get('getResult')
+                    if 'getResult' in solcatcherSettings and get_result != False:
+                        if get_result in [True,None]:
+                            get_result = 'result'
+                        result = result.get(get_result,result)
+                    return result
+
+        elif result:
+            return result
+    # If no response after all attempts, return empty or raise an exception
+    return []
+def get_url_request(url=None, payload={}, headers=None, url_1_only=None, url_2_only=False,*args, **kwargs):
     if url == None:
         if (url_1_only == None and url_2_only==None) or (url_1_only and not url_2_only):
             url = solana_rpc_url
         elif (not url_1_only and url_2_only) or (url_1_only and url_2_only):
             url = fall_back_rpc
     url = url or solana_rpc_url
-    return get_async_response(async_make_request,url=url,payload=payload,headers=headers or get_headers())
+    return url
 def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
-    return get_async_response(async_call_rate_limiter,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs)
-
-def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
-    return get_async_response(async_make_rate_limited_call(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs))
-
-def call_solcatcher_py(endpoint, *args, **kwargs):
-    return get_async_response(async_call_solcatcher_py,endpoint, *args, **kwargs)
+    return call_rate_limiter(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs)
 
 def call_solcatcher_ts(endpoint, *args, **kwargs):
-    return get_async_response(async_call_solcatcher_ts,endpoint, *args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    url = getSolcatcherTsUrl(endpoint=endpoint)
+    response = make_request(url, payload, headers=headers)
+    result = runSolcatcherSettings(response, solcatcherSettings)
+    return result
+
+def call_solcatcher_py(endpoint, *args, **kwargs):
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    url = getSolcatcherPairCatchUrl(endpoint=endpoint)
+    response = make_request(url, payload, headers=headers)
+    result = runSolcatcherSettings(response, solcatcherSettings)
+    return result
 
 def call_solcatcher_db(endpoint, *args, **kwargs):
-    return get_async_response(async_call_solcatcher_db,endpoint, *args, **kwargs)
-
+    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    url = getSolcatcherDbCalls(endpoint=endpoint)
+    response = make_request(url, payload, headers=headers)
+    result = runSolcatcherSettings(response, solcatcherSettings)
+    return result
 
