@@ -7,12 +7,13 @@ def get_all_txns(pair_id):
     transactions = call_solcatcher_db('/api/get_transactions',pair_id)
     return transactions
 def process_logs(transaction):
-    signature = get_any_value(transaction, 'signatures')[0]
-    slot = get_any_value(transaction, 'slot')
-    logs = get_any_value(transaction, 'logMessages')
-    program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
-    response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
-    return signature
+    signature = get_any_value(transaction, 'signatures')
+    if signature:
+        slot = get_any_value(transaction, 'slot')
+        logs = get_any_value(transaction, 'logMessages')
+        program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
+        response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
+        return signature
 def get_pair(pair_id=None,mint=None,signature=None):
     try:
         raw_pair_data = call_solcatcher_db('/api/get_pair',mint=mint,pair_id=pair_id,signature=signature)
